@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
-import bleach
-
 from django import forms
-from django.core.exceptions import ImproperlyConfigured
-
 from django.conf import settings
+from django.core.exceptions import ImproperlyConfigured
 from django.utils.safestring import mark_safe
+
+import bleach
+import warnings
+from bleach.css_sanitizer import CSSSanitizer
 from importlib import import_module
 
 from django_bleach.utils import get_bleach_default_options
@@ -25,7 +25,7 @@ def load_widget(path):
         cls = getattr(mod, attr)
     except AttributeError:
         raise ImproperlyConfigured(
-            "Module '%s' does not define a '%s' widget" % (module, attr)
+            f"Module '{module}' does not define a '{attr}' widget"
         )
 
     return cls
@@ -45,11 +45,11 @@ class BleachField(forms.CharField):
 
     def __init__(self, allowed_tags=None, allowed_attributes=None,
                  allowed_styles=None, allowed_protocols=None,
-                 strip_comments=None, strip_tags=None, *args, **kwargs):
+                 strip_comments=None, strip_tags=None, css_sanitizer=None, *args, **kwargs):
 
         self.widget = get_default_widget()
 
-        super(BleachField, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
         self.bleach_options = get_bleach_default_options()
 
@@ -58,7 +58,16 @@ class BleachField(forms.CharField):
         if allowed_attributes is not None:
             self.bleach_options["attributes"] = allowed_attributes
         if allowed_styles is not None:
-            self.bleach_options["styles"] = allowed_styles
+            warnings.warn(
+                "allowed_styles will be deprecated, use css_sanitizer instead",
+                DeprecationWarning
+            )
+
+            if css_sanitizer:
+                warnings.warn("allowed_styles argument is ignored since css_sanitizer is favoured over allowed_styles")
+            self.bleach_options["css_sanitizer"] = CSSSanitizer(allowed_css_properties=allowed_styles)
+        if css_sanitizer is not None:
+            self.bleach_options["css_sanitizer"] = css_sanitizer
         if allowed_protocols is not None:
             self.bleach_options["protocols"] = allowed_protocols
         if strip_tags is not None:
